@@ -49,7 +49,6 @@ impl<'run, 'src> Analyzer<'run, 'src> {
         match item {
           Item::Alias(alias) => {
             Self::define(&mut definitions, alias.name, "alias", false)?;
-            Self::analyze_alias(alias)?;
             self.aliases.insert(alias.clone());
           }
           Item::Assignment(assignment) => {
@@ -65,32 +64,16 @@ impl<'run, 'src> Analyzer<'run, 'src> {
           }
           Item::Module {
             absolute,
-            name,
             doc,
-            attributes,
+            groups,
+            name,
             ..
           } => {
-            let mut doc_attr: Option<&str> = None;
-            let mut groups = Vec::new();
-            for attribute in attributes {
-              if let Attribute::Doc(ref doc) = attribute {
-                doc_attr = Some(doc.as_ref().map(|s| s.cooked.as_ref()).unwrap_or_default());
-              } else if let Attribute::Group(ref group) = attribute {
-                groups.push(group.cooked.clone());
-              } else {
-                return Err(name.token.error(InvalidAttribute {
-                  item_kind: "Module",
-                  item_name: name.lexeme(),
-                  attribute: attribute.clone(),
-                }));
-              }
-            }
-
             if let Some(absolute) = absolute {
               Self::define(&mut definitions, *name, "module", false)?;
               self.modules.insert(Self::analyze(
                 asts,
-                doc_attr.or(*doc).map(ToOwned::to_owned),
+                doc.clone(),
                 groups.as_slice(),
                 loaded,
                 Some(*name),
@@ -170,11 +153,9 @@ impl<'run, 'src> Analyzer<'run, 'src> {
     }
 
     for recipe in recipes.values() {
-      for attribute in &recipe.attributes {
-        if let Attribute::Script(_) = attribute {
-          unstable_features.insert(UnstableFeature::ScriptAttribute);
-          break;
-        }
+      if recipe.attributes.contains(AttributeDiscriminant::Script) {
+        unstable_features.insert(UnstableFeature::ScriptAttribute);
+        break;
       }
     }
 
@@ -182,6 +163,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
       unstable_features.insert(UnstableFeature::ScriptInterpreterSetting);
     }
 
+    let source = root.to_owned();
     let root = paths.get(root).unwrap();
 
     Ok(Justfile {
@@ -198,14 +180,14 @@ impl<'run, 'src> Analyzer<'run, 'src> {
             Rc::clone(next)
           }),
         }),
-      doc,
+      doc: doc.filter(|doc| !doc.is_empty()),
       groups: groups.into(),
       loaded: loaded.into(),
       modules: self.modules,
       name,
       recipes,
       settings,
-      source: root.into(),
+      source,
       unexports: self.unexports,
       unstable_features,
       warnings: self.warnings,
@@ -284,11 +266,7 @@ impl<'run, 'src> Analyzer<'run, 'src> {
     }
 
     if !recipe.is_script() {
-      if let Some(attribute) = recipe
-        .attributes
-        .iter()
-        .find(|attribute| matches!(attribute, Attribute::Extension(_)))
-      {
+      if let Some(attribute) = recipe.attributes.get(AttributeDiscriminant::Extension) {
         return Err(recipe.name.error(InvalidAttribute {
           item_kind: "Recipe",
           item_name: recipe.name.lexeme(),
@@ -300,20 +278,6 @@ impl<'run, 'src> Analyzer<'run, 'src> {
     Ok(())
   }
 
-  fn analyze_alias(alias: &Alias<'src, Name<'src>>) -> CompileResult<'src> {
-    for attribute in &alias.attributes {
-      if *attribute != Attribute::Private {
-        return Err(alias.name.token.error(InvalidAttribute {
-          item_kind: "Alias",
-          item_name: alias.name.lexeme(),
-          attribute: attribute.clone(),
-        }));
-      }
-    }
-
-    Ok(())
-  }
-
   fn analyze_set(&self, set: &Set<'src>) -> CompileResult<'src> {
     if let Some(original) = self.sets.get(set.name.lexeme()) {
       return Err(set.name.error(DuplicateSet {
