@@ -6,31 +6,98 @@
 
 pub(crate) use {
   crate::{
-    alias::Alias, analyzer::Analyzer, argument_parser::ArgumentParser, assignment::Assignment,
-    assignment_resolver::AssignmentResolver, ast::Ast, attribute::Attribute, binding::Binding,
-    color::Color, color_display::ColorDisplay, command_color::CommandColor,
-    command_ext::CommandExt, compilation::Compilation, compile_error::CompileError,
-    compile_error_kind::CompileErrorKind, compiler::Compiler, condition::Condition,
-    conditional_operator::ConditionalOperator, config::Config, config_error::ConfigError,
-    constants::constants, count::Count, delimiter::Delimiter, dependency::Dependency,
-    dump_format::DumpFormat, enclosure::Enclosure, error::Error, evaluator::Evaluator,
-    execution_context::ExecutionContext, executor::Executor, expression::Expression,
-    fragment::Fragment, function::Function, interpreter::Interpreter,
-    interrupt_guard::InterruptGuard, interrupt_handler::InterruptHandler, item::Item,
-    justfile::Justfile, keyed::Keyed, keyword::Keyword, lexer::Lexer, line::Line, list::List,
-    load_dotenv::load_dotenv, loader::Loader, module_path::ModulePath, name::Name,
-    namepath::Namepath, ordinal::Ordinal, output::output, output_error::OutputError,
-    parameter::Parameter, parameter_kind::ParameterKind, parser::Parser, platform::Platform,
-    platform_interface::PlatformInterface, position::Position, positional::Positional, ran::Ran,
-    range_ext::RangeExt, recipe::Recipe, recipe_resolver::RecipeResolver,
-    recipe_signature::RecipeSignature, scope::Scope, search::Search, search_config::SearchConfig,
-    search_error::SearchError, set::Set, setting::Setting, settings::Settings, shebang::Shebang,
-    show_whitespace::ShowWhitespace, source::Source, string_delimiter::StringDelimiter,
-    string_kind::StringKind, string_literal::StringLiteral, subcommand::Subcommand,
-    suggestion::Suggestion, table::Table, thunk::Thunk, token::Token, token_kind::TokenKind,
-    unresolved_dependency::UnresolvedDependency, unresolved_recipe::UnresolvedRecipe,
-    unstable_feature::UnstableFeature, use_color::UseColor, variables::Variables,
-    verbosity::Verbosity, warning::Warning,
+    alias::Alias,
+    alias_style::AliasStyle,
+    analyzer::Analyzer,
+    argument_parser::ArgumentParser,
+    assignment::Assignment,
+    assignment_resolver::AssignmentResolver,
+    ast::Ast,
+    attribute::{Attribute, AttributeDiscriminant},
+    attribute_set::AttributeSet,
+    binding::Binding,
+    color::Color,
+    color_display::ColorDisplay,
+    command_color::CommandColor,
+    command_ext::CommandExt,
+    compilation::Compilation,
+    compile_error::CompileError,
+    compile_error_kind::CompileErrorKind,
+    compiler::Compiler,
+    condition::Condition,
+    conditional_operator::ConditionalOperator,
+    config::Config,
+    config_error::ConfigError,
+    constants::constants,
+    count::Count,
+    delimiter::Delimiter,
+    dependency::Dependency,
+    dump_format::DumpFormat,
+    enclosure::Enclosure,
+    error::Error,
+    evaluator::Evaluator,
+    execution_context::ExecutionContext,
+    executor::Executor,
+    expression::Expression,
+    fragment::Fragment,
+    function::Function,
+    interpreter::Interpreter,
+    interrupt_guard::InterruptGuard,
+    interrupt_handler::InterruptHandler,
+    item::Item,
+    justfile::Justfile,
+    keyed::Keyed,
+    keyword::Keyword,
+    lexer::Lexer,
+    line::Line,
+    list::List,
+    load_dotenv::load_dotenv,
+    loader::Loader,
+    module_path::ModulePath,
+    name::Name,
+    namepath::Namepath,
+    ordinal::Ordinal,
+    output::output,
+    output_error::OutputError,
+    parameter::Parameter,
+    parameter_kind::ParameterKind,
+    parser::Parser,
+    platform::Platform,
+    platform_interface::PlatformInterface,
+    position::Position,
+    positional::Positional,
+    ran::Ran,
+    range_ext::RangeExt,
+    recipe::Recipe,
+    recipe_resolver::RecipeResolver,
+    recipe_signature::RecipeSignature,
+    scope::Scope,
+    search::Search,
+    search_config::SearchConfig,
+    search_error::SearchError,
+    set::Set,
+    setting::Setting,
+    settings::Settings,
+    shebang::Shebang,
+    show_whitespace::ShowWhitespace,
+    source::Source,
+    string_delimiter::StringDelimiter,
+    string_kind::StringKind,
+    string_literal::StringLiteral,
+    subcommand::Subcommand,
+    suggestion::Suggestion,
+    table::Table,
+    thunk::Thunk,
+    token::Token,
+    token_kind::TokenKind,
+    unresolved_dependency::UnresolvedDependency,
+    unresolved_recipe::UnresolvedRecipe,
+    unstable_feature::UnstableFeature,
+    use_color::UseColor,
+    variables::Variables,
+    verbosity::Verbosity,
+    warning::Warning,
+    which::which,
   },
   camino::Utf8Path,
   clap::ValueEnum,
@@ -114,12 +181,14 @@ pub mod summary;
 pub mod request;
 
 mod alias;
+mod alias_style;
 mod analyzer;
 mod argument_parser;
 mod assignment;
 mod assignment_resolver;
 mod ast;
 mod attribute;
+mod attribute_set;
 mod binding;
 mod color;
 mod color_display;
@@ -205,3 +274,4 @@ mod use_color;
 mod variables;
 mod verbosity;
 mod warning;
+mod which;
