@@ -25,10 +25,10 @@ mod full {
   };
 }
 
-pub fn summary(path: &Path) -> Result<Result<Summary, String>, io::Error> {
+pub fn summary(path: &Path) -> io::Result<Result<Summary, String>> {
   let loader = Loader::new();
 
-  match Compiler::compile(false, &loader, path) {
+  match Compiler::compile(&loader, path) {
     Ok(compilation) => Ok(Ok(Summary::new(&compilation.justfile))),
     Err(error) => Ok(Err(if let Error::Compile { compile_error } = error {
       compile_error.to_string()
@@ -183,6 +183,10 @@ impl Assignment {
 
 #[derive(Eq, PartialEq, Hash, Ord, PartialOrd, Debug, Clone)]
 pub enum Expression {
+  And {
+    lhs: Box<Expression>,
+    rhs: Box<Expression>,
+  },
   Assert {
     condition: Condition,
     error: Box<Expression>,
@@ -209,6 +213,10 @@ pub enum Expression {
     lhs: Option<Box<Expression>>,
     rhs: Box<Expression>,
   },
+  Or {
+    lhs: Box<Expression>,
+    rhs: Box<Expression>,
+  },
   String {
     text: String,
   },
@@ -221,6 +229,10 @@ impl Expression {
   fn new(expression: &full::Expression) -> Self {
     use full::Expression::*;
     match expression {
+      And { lhs, rhs } => Self::And {
+        lhs: Self::new(lhs).into(),
+        rhs: Self::new(rhs).into(),
+      },
       Assert {
         condition: full::Condition { lhs, rhs, operator },
         error,
@@ -250,11 +262,9 @@ impl Expression {
           ..
         } => {
           let mut arguments = Vec::new();
-
           if let Some(b) = opt_b.as_ref() {
             arguments.push(Self::new(b));
           }
-
           arguments.push(Self::new(a));
           Self::Call {
             name: name.lexeme().to_owned(),
@@ -308,10 +318,6 @@ impl Expression {
         lhs: Self::new(lhs).into(),
         rhs: Self::new(rhs).into(),
       },
-      Join { lhs, rhs } => Self::Join {
-        lhs: lhs.as_ref().map(|lhs| Self::new(lhs).into()),
-        rhs: Self::new(rhs).into(),
-      },
       Conditional {
         condition: full::Condition { lhs, rhs, operator },
         otherwise,
@@ -323,13 +329,21 @@ impl Expression {
         rhs: Self::new(rhs).into(),
         then: Self::new(then).into(),
       },
+      Group { contents } => Self::new(contents),
+      Join { lhs, rhs } => Self::Join {
+        lhs: lhs.as_ref().map(|lhs| Self::new(lhs).into()),
+        rhs: Self::new(rhs).into(),
+      },
+      Or { lhs, rhs } => Self::Or {
+        lhs: Self::new(lhs).into(),
+        rhs: Self::new(rhs).into(),
+      },
       StringLiteral { string_literal } => Self::String {
         text: string_literal.cooked.clone(),
       },
       Variable { name, .. } => Self::Variable {
         name: name.lexeme().to_owned(),
       },
-      Group { contents } => Self::new(contents),
     }
   }
 }
@@ -346,6 +360,7 @@ pub enum ConditionalOperator {
   Equality,
   Inequality,
   RegexMatch,
+  RegexMismatch,
 }
 
 impl ConditionalOperator {
@@ -354,6 +369,7 @@ impl ConditionalOperator {
       full::ConditionalOperator::Equality => Self::Equality,
       full::ConditionalOperator::Inequality => Self::Inequality,
       full::ConditionalOperator::RegexMatch => Self::RegexMatch,
+      full::ConditionalOperator::RegexMismatch => Self::RegexMismatch,
     }
   }
 }
