@@ -6,15 +6,15 @@ pub(crate) struct UnresolvedDependency<'src> {
   pub(crate) arguments: Vec<Expression<'src>>,
 }
 
-impl<'src> Display for UnresolvedDependency<'src> {
-  fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
+impl Display for UnresolvedDependency<'_> {
+  fn fmt(&self, f: &mut Formatter) -> fmt::Result {
     if self.arguments.is_empty() {
       write!(f, "{}", self.recipe)
     } else {
       write!(f, "({}", self.recipe)?;
 
       for argument in &self.arguments {
-        write!(f, " {}", argument)?;
+        write!(f, " {argument}")?;
       }
 
       write!(f, ")")
