@@ -11,20 +11,39 @@ test! {
   args: ("--list"),
   stdout: "
     Available recipes:
-        foo
-        f   # alias for `foo`
+        foo # [alias: f]
   ",
 }
 
+#[test]
+fn alias_listing_with_doc() {
+  Test::new()
+    .justfile(
+      "
+        # foo command
+        foo:
+          echo foo
+
+        alias f := foo
+      ",
+    )
+    .arg("--list")
+    .stdout(
+      "
+      Available recipes:
+          foo # foo command [alias: f]
+    ",
+    )
+    .run();
+}
+
 test! {
   name: alias_listing_multiple_aliases,
   justfile: "foo:\n  echo foo\nalias f := foo\nalias fo := foo",
   args: ("--list"),
   stdout: "
     Available recipes:
-        foo
-        f   # alias for `foo`
-        fo  # alias for `foo`
+        foo # [aliases: f, fo]
   ",
 }
 
@@ -34,8 +53,7 @@ test! {
   args: ("--list"),
   stdout: "
     Available recipes:
-        foo PARAM='foo'
-        f PARAM='foo'   # alias for `foo`
+        foo PARAM='foo' # [alias: f]
   ",
 }
 
@@ -927,8 +945,7 @@ a:
   stdout:   r"
     Available recipes:
         a
-        b
-        c # alias for `b`
+        b # [alias: c]
   ",
 }
 
@@ -942,8 +959,7 @@ a:
   args:     ("--list", "--unsorted"),
   stdout:   r"
     Available recipes:
-        b
-        c # alias for `b`
+        b # [alias: c]
         a
   ",
 }
